==> issetbv-video-archive-filehandler-client-0.3.2-385567.zip: IssetBV/FileHandlerClient/Folder/Folders.php <==
<?php
namespace IssetBV\FileHandlerClient\Folder;

use GuzzleHttp\Client as GuzzleClient;

class Folders
{

    /**
     * @var GuzzleClient
     */
    private $client;

    /**
     * 
     * @var array
     */
    private $defaultDivisions;

    /**
     * 
     * @param GuzzleClient $client
     * @param array $defaultDivisions
     */
    public function __construct(GuzzleClient $client, array $defaultDivisions = array())
    {
        $this->client = $client;
        $this->defaultDivisions = $defaultDivisions;
    }

    /**
     * 
     * @param string $name
     * @param array $divisions
     * @return \IssetBV\FileHandlerClient\Folder\Folder
     */
    public function create($name, $parentFolderUuid = null, array $divisions = null)
    {
        if ($divisions === null) {
            $divisions = $this->defaultDivisions;
        }
        $content = $this->client->post("folder", [
            'json' => [
                'name' => $name,
                'divisions' => $divisions,
                'parent_folder_uuid' => $parentFolderUuid
            ]
        ])
            ->getBody()
            ->getContents();
        return new Folder($this->client, $content);
    }

    /**
     * 
     * @param string $uuid
     * @param array $divisions
     * @return \IssetBV\FileHandlerClient\Folder\Folder
     */
    public function get($uuid, array $divisions = null)
    {
        return $this->getFolder($uuid, $divisions);
    }

    /**
     * 
     * @param string $uuid
     * @param array $divisions 
     * @return \IssetBV\FileHandlerClient\Folder\Folder
     */
    public function getFolder($uuid, array $divisions = null)
    {
        if ($divisions === null) {
            $divisions = $this->defaultDivisions;
        }
        $content = $this->client->get("folder/" . $uuid, [
            'query' => [
                'divisions' => $divisions
            ]
        ])
            ->getBody()
            ->getContents();
        return new Folder($this->client, $content);
    }

    /**
     * 
     * @param array $divisions
     * @return multitype:\IssetBV\FileHandlerClient\Folder\Folder
     */
    public function getList(array $divisions = null)
    {
        if ($divisions === null) {
            $divisions = $this->defaultDivisions;
        }
        $data = $this->client->get("folders", [
            'query' => [
                'divisions' => $divisions
            ]
        ])
            ->getBody()
            ->getContents();
        $folders = json_decode($data);
        $return = array();
        
        foreach ($folders as $folder) {
            $return[] = new Folder($this->client, $folder);
        }
        
        return $return;
    }
}

==> issetbv-video-archive-filehandler-client-1.0.1-9008a1.zip: IssetBV/FileHandlerClient/Folder/Folders.php <==
<?php
namespace IssetBV\FileHandlerClient\Folder;

use GuzzleHttp\Client as GuzzleClient;

class Folders
{

    /**
     * @var GuzzleClient
     */
    private $client;

    /**
     * @param GuzzleClient $client
     */
    public function __construct(GuzzleClient $client)
    {
        $this->client = $client;
    }

    /**
     * @param string $name
     * @param string $parentFolderUuid
     * @return \IssetBV\FileHandlerClient\Folder\Folder
     */
    public function create($name, $parentFolderUuid = null)
    {
        $content = $this->client->post("folder", [
            'json' => [
                'name' => $name,
                'divisions' => [],
                'parent_folder_uuid' => $parentFolderUuid
            ]
        ])
            ->getBody()
            ->getContents();
        return new Folder($this->client, $content);
    }

    /**
     * @param string $uuid
     * @return \IssetBV\FileHandlerClient\Folder\Folder
     */
    public function get($uuid)
    {
        return $this->getFolder($uuid);
    }

    /**
     * @param string $uuid
     * @return \IssetBV\FileHandlerClient\Folder\Folder
     */
    public function getFolder($uuid)
    {
        $content = $this->client->get("folder/" . $uuid)
            ->getBody()
            ->getContents();
        return new Folder($this->client, $content);
    }

    /**
     * @return multitype:\IssetBV\FileHandlerClient\Folder\Folder
     */
    public function getSharedList()
    {
        $data = $this->client->get("folders/shared")
            ->getBody()
            ->getContents();
        $folders = json_decode($data);
        $return = array();
        
        foreach ($folders as $folder) {
            $return[] = new Folder($this->client, $folder);
        }
        
        return $return;
    }

    public function claim($token, $email)
    {
        return json_decode($this->client->get("folder/share/" . $token . "/" . $email)
            ->getBody()
            ->getContents());
    }

    /**
     * @param array $divisions
     * @return multitype:\IssetBV\FileHandlerClient\Folder\Folder
     */
    public function getList()
    {
        $data = $this->client->get("folders")
            ->getBody()
            ->getContents();
        $folders = json_decode($data);
        $return = array();
        
        foreach ($folders as $folder) {
            $return[] = new Folder($this->client, $folder);
        }
        
        return $return;
    }
}
